==> zippa-0.1.0.tgz: package/lib/test/testTreeZipper.js <==
'use strict';

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _sinonChai = require('sinon-chai');

var _sinonChai2 = _interopRequireDefault(_sinonChai);

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

_chai2.default.use(_sinonChai2.default);
var expect = _chai2.default.expect;

var Node = function Node(data) {
    var children = arguments.length <= 1 || arguments[1] === undefined ? [] : arguments[1];

    _classCallCheck(this, Node);

    this.data = data;
    this.children = children;
};

function getChildren(node) {
    return node.children;
}

function makeNode(node, children) {
    return new Node(node.data, children);
}

function isBranch(node) {
    return !!getChildren(node).length;
}

var log = function log(node) {
    console.log(node.data);
};

describe('TreeZipper', function () {
    function getTree() {
        return new Node(1, [new Node(2, [new Node(4), new Node(5)]), new Node(3)]);
    }

    var Zipper = (0, _index2.default)(isBranch, getChildren, makeNode);

    function dfswalk(z) {
        var _z = z;
        var result = [];
        while (!_z.isEnd()) {
            result.push(_z.value().data);
            _z = _z.next();
        }
        return result;
    }

    it('DFS iteration works', function () {
        var z = Zipper.from(getTree());

        var iterationOrder = [];
        while (!z.isEnd()) {
            iterationOrder.push(z.value().data);
            z = z.next();
        }

        var expected = [1, 2, 4, 5, 3];

        expect(iterationOrder).to.deep.equal(expected);
    });

    it('replacing works', function () {
        var z = Zipper.from(getTree());
        var changedZipper = z.down().rightmost().remove().root();

        var dfsorder = dfswalk(changedZipper);
        expect(dfsorder).to.deep.equal([1, 2, 4, 5]);
    });
});

==> zippa-0.2.0.tgz: package/lib/test/testTreeZipper.js <==
'use strict';

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _sinonChai = require('sinon-chai');

var _sinonChai2 = _interopRequireDefault(_sinonChai);

var _index = require('../index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

_chai2.default.use(_sinonChai2.default);
var expect = _chai2.default.expect;

var Node = function Node(data) {
    var children = arguments.length <= 1 || arguments[1] === undefined ? [] : arguments[1];

    _classCallCheck(this, Node);

    this.data = data;
    this.children = children;
};

function getChildren(node) {
    return node.children;
}

function makeNode(node, children) {
    return new Node(node.data, children);
}

function isBranch(node) {
    return !!getChildren(node).length;
}

var log = function log(node) {
    console.log(node.data);
};

describe('TreeZipper', function () {
    function getTree() {
        return new Node(1, [new Node(2, [new Node(4), new Node(5)]), new Node(3)]);
    }

    var Zipper = (0, _index.makeZipper)(isBranch, getChildren, makeNode);

    function dfswalk(z) {
        var _z = z;
        var result = [];
        while (!_z.isEnd()) {
            result.push(_z.value().data);
            _z = _z.next();
        }
        return result;
    }

    it('DFS iteration works', function () {
        var z = Zipper.from(getTree());

        var iterationOrder = [];
        while (!z.isEnd()) {
            iterationOrder.push(z.value().data);
            z = z.next();
        }

        var expected = [1, 2, 4, 5, 3];

        expect(iterationOrder).to.deep.equal(expected);
    });

    it('replacing works', function () {
        var z = Zipper.from(getTree());
        var changedZipper = z.down().rightmost().remove().root();

        var dfsorder = dfswalk(changedZipper);
        expect(dfsorder).to.deep.equal([1, 2, 4, 5]);
    });
});
